---
name: "\U0001F31F Feature and enhancement requests"
about: Suggest an idea that would improve the project.
title: ''
labels: ''
assignees: ''

---

<!-- Thank you for taking the time to create this request. Your feedback is appreciated ! -->

## What component is this about ?
<!-- The API or the API clients ? The Ansible roles or plugins ? Something else ? -->
<!-- For ara-web issues, please use https://github.com/ansible-community/ara-web/issues -->


## What is your ARA installation like ?
<!-- What version of Ansible and ARA ? Did you install from source or from PyPi ? With an Ansible role ? In a virtualenv or a container ? Which Linux distribution ? Which database driver ? -->
<!-- Feel free to include any other installation details that could be relevant to this report -->


## What is the idea ?
<!-- Describe how the feature would be used, why it is needed and what it would solve -->
<!-- If relevant, please include code or playbook examples -->

